/* ************************************************************************
 *  (c) by Karl-Heinz Kuebbeler, Projekt Transistor Tester
 *  
 *  File:       6x8_vertikal_LSB_2.h
 *  Funktion:   (table of the bits for the 6x8 character set)
 *              - 6 bytes per character
 *              - first byte: first vertical line (left to right)
 *              - bit #0: top / bit #7: bottom (vertically flipped)
 * 
 * History:     Date        Sign    Kommentar 
 *              2021-01-11  Bohu    LANG_SLOVAK
 *              2021-01-13  Karl    Reihenfolge der Zeichen 4-16 geaendert
 *              2021-01-14  Karl    #define der Symbol-Position
 *              2021-01-23  Bohu    ISO 8859-2 und 15 getrennt  
 * ************************************************************************ */

#if defined LCD_CYRILLIC
 #define CHAR_COUNT 0xa0
#else
 /* ---------------------------------- */
 #if defined LANG_CZECH || defined LANG_SLOVAK
/* ---------de ISO8859-2---------- */
  #define a_acute       0x10 /* e1 */
  #define a_uml         0x11 /* e4 */
  #define c_caron       0x12 /* e8 */
  #define d_caron       0x13 /* ef */
  #define e_acute       0x14 /* e9 */
  #define e_caron       0x15 /* ec */
  #define i_acute       0x16 /* ed */
  #define l_acute       0x17 /* e5 */
  #define l_caron       0x18 /* b5 */
  #define n_caron       0x19 /* f2 */
  #define o_acute       0x1a /* f3 */
  #define o_uml         0x1b /* f6 */
  #define o_circ        0x1c /* f4 */
  #define r_acute       0x1d /* e0 */
  #define r_caron       0x1e /* f8 */
  #define s_caron       0x1f /* b9 */

  #define t_caron       0x80 /* bb */
  #define u_acute       0x81 /* fa */
  #define u_uml         0x82 /* fc */
  #define u_ring        0x83 /* f9 */
  #define y_acute       0x84 /* fd */
  #define z_caron       0x85 /* b9 */
  #define A_acute       0x86 /* c1 */
  #define A_uml         0x87 /* c4 */
  #define C_caron       0x88 /* c8 */
  #define D_caron       0x89 /* cf */
  #define E_acute       0x8a /* c9 */
  #define E_caron       0x8b /* cc */
  #define I_acute       0x8c /* cd */
  #define L_acute       0x8d /* c5 */
  #define L_caron       0x8e /* a5 */
  #define N_caron       0x8f /* d2 */
  #define O_acute       0x90 /* d3 */
  #define O_uml         0x91 /* d6 */
  #define O_circ        0x92 /* d4 */
  #define R_acute       0x93 /* c0 */
  #define R_caron       0x94 /* d8 */
  #define S_caron       0x95 /* a9 */
  #define T_caron       0x96 /* ab */
  #define U_acute       0x97 /* da */
  #define U_uml         0x98 /* dc */
  #define Y_acute       0x99 /* dd */
  #define Z_caron       0x9a /* ae */
  #define CHAR_COUNT 0x9b
 /* ------------------------------ */
 #elif defined LANG_FRANCAIS
   // Caract?res accentues francais ISO8859-15
  #define a_grave       0x10 /* e0 */
  #define a_circ        0x11 /* e2 */
  #define a_elig        0x12 /* e6 */
  #define c_cedil       0x13 /* e7 */
  #define e_acute       0x14 /* e9 */
  #define e_circ        0x15 /* ea */
  #define e_grave       0x16 /* e8 */
  #define e_uml         0x17 /* eb */
  #define i_circ        0x18 /* ee */
  #define i_uml         0x19 /* ef */
  #define o_circ        0x1a /* f4 */
  #define o_elig        0x1b /* bd */
  #define u_grave       0x1c /* f9 */
  #define u_circ        0x1d /* fb */
  #define u_uml         0x1e /* fc */
  #define y_uml         0x1f /* ff */
  #define CHAR_COUNT 0x80
 /* ------------------------------ */
 #elif defined LANG_POLISH
  #define a_ogon        0x10 /* b1 */
  #define c_acute       0x11 /* e6 */
  #define e_ogon        0x12 /* ea */
  #define l_stroke      0x13 /* b3 */
  #define n_acute       0x14 /* f1 */
  #define o_acute       0x15 /* f3 */
  #define s_acute       0x16 /* b6 */
  #define z_acute       0x17 /* bc */
  #define z_dot         0x18 /* bf */
  #define A_ogon        0x19 /* a1 */
  #define C_acute       0x1a /* c6 */
  #define E_ogon        0x1b /* ca */
  #define L_stroke      0x1c /* a3 */
  #define N_acute       0x1d /* d1 */
  #define O_acute       0x1e /* d3 */
  #define S_acute       0x1f /* a6 */
  #define Z_acute       0x80 /* ac */
  #define Z_dot         0x81 /* ae */
 #define CHAR_COUNT  0x82
 /* ------------------------------ */
 #elif defined LANG_GERMAN || defined LANG_ALBANIAN
  #define a_uml      	0x10 /* e4 */
  #define c_cedil       0x11 /* e7 */
  #define e_uml      	0x12 /* f6 */
  #define o_uml      	0x13 /* f6 */
  #define s_sharp       0x14 /* df */
  #define u_uml      	0x15 /* fc */
  #define A_uml      	0x16 /* c4 */
  #define C_cedil       0x17 /* c7 */
  #define E_uml      	0x18 /* d6 */
  #define O_uml      	0x19 /* d6 */
  #define U_uml      	0x1a /* dc */
  #define CHAR_COUNT   128 // 0x7f + 1
 /* ------------------------------ */
  #elif defined LANG_HUNGARIAN
  #define a_acute       0x10 /* e1 */
  #define e_acute       0x11 /* e9 */
  #define o_acute       0x12 /* f3 */
  #define o_dblac       0x13 /* f5 */
  #define o_uml         0x14 /* f6 */
  #define u_acute       0x15 /* fa */
  #define u_dblac       0x16 /* fb */
  #define u_uml         0x17 /* fc */
  #define A_acute       0x18 /* c1 */
  #define E_acute       0x19 /* c9 */
  #define O_acute       0x1a /* d3 */
  #define O_dblac       0x1b /* d5 */
  #define O_uml         0x1c /* d6 */
  #define U_acute       0x1d /* da */
  #define U_dblac       0x1e /* db */
  #define U_uml         0x1f /* dc */
#define CHAR_COUNT   128 // 0x7f + 1
  #elif defined LANG_ROMANIAN  || LANG_DANISH
  #define a_circ        0x10 /* RO e2 */
  #define a_breve       0x11 /* RO e3 */
  #define a_ring        0x12 /* DK e5 */
  #define a_elig        0x13 /* DK e6 */
  #define i_circ        0x14 /* RO ee */
  #define o_slash       0x15 /* DK f8 */
  #define s-cedil       0x16 /* RO ba */
  #define t-cedil       0x17 /* RO fe */
  #define A_circ        0x18 /* RO c2 */
  #define A_breve       0x19 /* RO c3 */
  #define A_ring        0x1a /* DK c5 */
  #define A_elig        0x1b /* DK c6 */
  #define I_circ        0x1c /* RO ce */
  #define O_slash       0x1d /* DK d8 */
  #define S-cedil       0x1e /* RO aa */
  #define T-cedil       0x1f /* RO de */
 #define CHAR_COUNT   128 // 0x7f + 1
 /* ------------------------------ */
 #else
  #define CHAR_COUNT 128 // 0x7f + 1              
 #endif
#endif

#define LastChar (CHAR_COUNT - 1)
                               
#if defined(MAIN_C)
const unsigned char PROGMEM font[CHAR_COUNT][FONT_WIDTH]=
{
{0x08,0x3E,0x22,0x22,0x3E,0x08},	/*(01) 0x00 Resistor3  */
{0x08,0x7F,0x3E,0x1C,0x08,0x7F},	/*     0x01 Diode1  */
{0x7F,0x08,0x1C,0x3E,0x7F,0x08},	/*     0x02 Diode2  */
{0x00,0x00,0x00,0x00,0x00,0x00},	/*     0x03 ' ' */
{0x7F,0x7F,0x00,0x00,0x7F,0x7F},	/*     0x04 Capacitor  */
{0x00,0x00,0x00,0x00,0x00,0x00},	/*     0x05 ' ' */
{0x3E,0x22,0x22,0x22,0x22,0x22},	/*     0x06 Resistor2  */
{0x22,0x22,0x22,0x22,0x22,0x3E},	/*     0x07 Resistor1  */
{0x08,0x08,0x08,0x08,0x08,0x08},	/*     0x08 Line1 */
{0x38,0x40,0x40,0x30,0x40,0x40},	/*(10) 0x09 Inductor1 */
{0x30,0x40,0x40,0x30,0x40,0x38},	/*     0x0a Inductor2 */
{0x00,0x00,0x00,0x00,0x00,0x00},	/*     0x0b ' ' */
{0x00,0x80,0x7E,0x01,0x49,0x36},	/*     0x0c Beta */
{0x00,0x58,0x64,0x04,0x64,0x58},	/*     0x0d Omega  */
{0x00,0x80,0x7C,0x40,0x40,0x3C},	/*     0x0e mu (?) */
{0x00,0x06,0x29,0x79,0x29,0x06},	/*     0x0f ,dr  (degree) */
//**************************************************************
 #if defined LANG_FRANCAIS
 {0x00,0x20,0x54,0x55,0x56,0x38},	/* 0x10 a_grave   e0 */
 {0x00,0x20,0x56,0x55,0x56,0x38},	/* 0x11 a_circ    e2 */
 {0x00,0x38,0x56,0x55,0x54,0x18},	/* 0x12 a_elig    e6 */
 {0x00,0x38,0x44,0x46,0x45,0x28},	/* 0x13 c_cedil   e7 */
 {0x00,0x38,0x54,0x56,0x55,0x08},	/* 0x14 e_acute   e9 */
 {0x00,0x38,0x56,0x55,0x56,0x18},	/* 0x15 e_circ    ea */
 {0x00,0x38,0x54,0x55,0x55,0x18},	/* 0x16 e_grave   e8 */
 {0x00,0x38,0x55,0x54,0x55,0x08},	/* 0x17 e_uml     eb */
 {0x00,0x00,0x02,0x7D,0x42,0x00},	/* 0x18 i_circ    ee */
 {0x00,0x00,0x01,0x78,0x41,0x00},	/* 0x19 i_uml     ef */
 {0x00,0x38,0x46,0x45,0x46,0x38},	/* 0x1a o_circ    f4 */
 {0x00,0x38,0x46,0x45,0x46,0x38},	/* 0x1b o_elig    bd */
 {0x00,0x3C,0x41,0x42,0x40,0x3C},	/* 0x1c u_grave   f9 */
 {0x00,0x3C,0x42,0x41,0x42,0x3C},	/* 0x1d u_circ    fb */
 {0x00,0x3C,0x41,0x40,0x41,0x3C},	/* 0x1e u_uml     fc */
 {0x00,0x9C,0xA1,0x60,0x3D,0x00},	/* 0x1f y_uml     ff */
//***********************************************************
 #elif defined LANG_CZECH || LANG_SLOVAK
 {0x00,0x20,0x54,0x56,0x55,0x78},	/* 0x10 ,a_acute   e1 */
 {0x00,0x20,0x55,0x54,0x55,0x78},	/* 0x11 ,a_uml     e4 */
 {0x00,0x38,0x45,0x46,0x45,0x28},	/* 0x12 ,c_caron   e8 */
 {0x00,0x38,0x44,0x45,0x44,0x7F},	/* 0x13 ,d_caron   ef */
 {0x00,0x38,0x54,0x56,0x55,0x08},	/* 0x14 ,e_acute   e9 */
 {0x00,0x38,0x55,0x52,0x55,0x08},	/* 0x15 ,e_caron   ec */
 {0x00,0x00,0x00,0x7A,0x41,0x00},	/* 0x16 ,i_acute   ed */
 {0x00,0x00,0x00,0x7E,0x01,0x00},	/* 0x17 'l_acute   e5 */
 {0x00,0x00,0x7F,0x7F,0x03,0x00},	/* 0x18 'l_caron   b5 */
 {0x00,0x7C,0x05,0x06,0x05,0x78},	/* 0x19 ,n_caron   f2 */
 {0x00,0x38,0x44,0x46,0x45,0x38},	/* 0x1a ,o_acute   f3 */
 {0x00,0x38,0x45,0x44,0x45,0x38},	/* 0x1b ,o_uml     f6 */
 {0x00,0x38,0x46,0x45,0x46,0x38},	/* 0x1c ,o_circ    f4 */
 {0x00,0x04,0x7A,0x05,0x04,0x08},	/* 0x1d ,r_acute   e0 */
 {0x00,0x05,0x7A,0x05,0x04,0x08},	/* 0x1e ,r_caron   f8 */
 {0x00,0x08,0x55,0x52,0x55,0x20},	/* 0x1f ,s_caron   b9 */
//**********************************************************
 #elif defined LANG_SERBIAN || LANG_CROATIAN || LANG_SLOWENIAN || LANG_BOSNIAN
 {0x00,0x38,0x44,0x46,0x45,0x28},	/* 0x10 ,c_acute   e6 */
 {0x00,0x38,0x45,0x42,0x45,0x28},	/* 0x11 ,c_caron   e8 */
 {0x00,0x38,0x44,0x54,0x7F,0x50},	/* 0x12 ,d_eth     f0 */
 {0x00,0x62,0x53,0x5A,0x4B,0x46},	/* 0x13 ,s_caron   b9 */
 {0x00,0x64,0x55,0x56,0x4D,0x00},	/* 0x14 ,z_caron   be */
 {0x00,0x3C,0x42,0x43,0x42,0x24},	/* 0x15 ,C_acute   c6 */
 {0x00,0x3C,0x43,0x42,0x43,0x24},	/* 0x16 ,C_caron   c8 */
 {0x08,0x7F,0x49,0x41,0x41,0x3E},	/* 0x17 ,D_eth     d0 */
 {0x00,0x24,0x4B,0x4A,0x53,0x24},	/* 0x18 ,S_caron   a9 */
 {0x00,0x08,0x55,0x52,0x55,0xBC},	/* 0x19 ,Z_caron   ae */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1a ,0 */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1b ,0 */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1c ,0 */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1d ,0 */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1e ,0 */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1f ,0 */
//************************************************************
 #elif defined LANG_POLISH
 {0x00,0x10,0x2A,0x2A,0x6A,0xBC},	/* 0x10 ,a_ogon    b1 */
 {0x00,0x38,0x44,0x46,0x45,0x28},	/* 0x11 ,c_acute   e6 */
 {0x00,0x1C,0x2A,0x2A,0x6A,0xA4},	/* 0x12 ,e_ogon    ea */
 {0x00,0x00,0x08,0x7F,0x44,0x00},	/* 0x13 ,l_stroke  b3 */
 {0x00,0x7C,0x04,0x06,0x05,0x78},	/* 0x14 ,n_acute   f1 */
 {0x00,0x38,0x44,0x46,0x45,0x38},	/* 0x15 ,o_acute   f3 */
 {0x00,0x08,0x54,0x56,0x55,0x20},	/* 0x16 ,s_acute   b6 */
 {0x00,0x64,0x54,0x56,0x4D,0x00},	/* 0x17 ,z_acute   bc */
 {0x00,0x64,0x55,0x54,0x4C,0x00},	/* 0x18 ,z_dot     bf */
 {0x00,0x7E,0x09,0x09,0x49,0xBE},	/* 0x19 ,A_ogon    a1 */
 {0x00,0x3C,0x42,0x43,0x42,0x24},	/* 0x1a ,C_acute   c6 */
 {0x00,0x3F,0x25,0x25,0x65,0xA1},	/* 0x1b ,E_ogon    ca */
 {0x08,0x7F,0x44,0x40,0x40,0x40},	/* 0x1c ,L_stroke  a3 */
 {0x00,0x7E,0x08,0x12,0x21,0x7E},	/* 0x1d ,N_acute   d1 */
 {0x00,0x38,0x44,0x46,0x45,0x38},	/* 0x1e ,O_acute   d3 */
 {0x00,0x24,0x4A,0x4B,0x52,0x24},	/* 0x1f ,S_acute   a6 */
//************************************************************
 #elif defined LANG_GERMAN || LANG_ALBANIAN
 {0x00,0x20,0x55,0x54,0x55,0x78},	/* 0x10 ,a_uml     e4 */
 {0x00,0x38,0x44,0x46,0x45,0x28},	/* 0x11 ,c_cedil   e7 */
 {0x00,0x38,0x55,0x54,0x55,0x08},	/* 0x12 ,e_uml     eb */
 {0x00,0x38,0x45,0x44,0x45,0x38},	/* 0x13 ,o_uml     f6 */
 {0x00,0xFE,0x4A,0x4A,0x34,0x00},	/* 0x14 ,s_sharp   df */
 {0x00,0x3C,0x41,0x40,0x41,0x3C},	/* 0x15 ,u_uml     fc */
 {0x00,0x78,0x25,0x26,0x25,0x78},	/* 0x16 ,A_uml     c4 */
 {0x00,0x1E,0xA1,0x61,0x21,0x12},	/* 0x17 ,C_cedil   c7 */
 {0x00,0x7C,0x55,0x54,0x55,0x44},	/* 0x18 ,E_uml     cb */
 {0x00,0x3D,0x42,0x42,0x3D,0x00},	/* 0x19 ,O_uml     d6 */
 {0x00,0x3C,0x41,0x40,0x41,0x3C},	/* 0x1a ,U_uml     dc */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1b ,0 */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1c ,0 */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1d ,0 */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1e ,0 */
 {0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x1f ,0 */  
//**********************************************************
 #elif defined LANG_HUNGARIAN
 {0x00,0x20,0x54,0x56,0x55,0x78},	/* 0x10 ,a_acute   e1 */
 {0x00,0x38,0x54,0x56,0x55,0x08},	/* 0x11 ,e_acute   e9 */
 {0x00,0x38,0x44,0x46,0x45,0x38},	/* 0x12 ,o_acute   f3 */
 {0x00,0x3A,0x45,0x44,0x46,0x39},	/* 0x13 ,o_dblac   f5 */
 {0x00,0x38,0x45,0x44,0x45,0x38},	/* 0x14 ,o_uml     f6 */
 {0x00,0x3C,0x40,0x42,0x41,0x3C},	/* 0x15 ,u_acute   fa */
 {0x00,0x3C,0x42,0x41,0x42,0x3D},	/* 0x16 ,u_dblac   fb */
 {0x00,0x3C,0x41,0x40,0x41,0x3C},	/* 0x17 ,u_uml     fc */
 {0x00,0x78,0x14,0x16,0x15,0x78},	/* 0x18 ,A_acute   c1 */
 {0x00,0x7C,0x54,0x56,0x55,0x44},	/* 0x19 ,E_acute   c9 */
 {0x00,0x38,0x44,0x46,0x45,0x38},	/* 0x1a ,O_acute   d3 */
 {0x00,0x3A,0x45,0x46,0x45,0x38},	/* 0x1b ,O_dblac   d5 */
 {0x00,0x3D,0x42,0x42,0x3D,0x00},	/* 0x1c ,O_uml     d6 */
 {0x00,0x3F,0x40,0x42,0x41,0x3F},	/* 0x1d ,U_acute   da */
 {0x00,0x3E,0x41,0x42,0x41,0x3E},	/* 0x1e ,U_dblac   db */
 {0x00,0x3C,0x41,0x40,0x41,0x3C},	/* 0x1f ,U_uml     dc */
//***********************************************************
 #elif defined LANG_ROMANIAN  || LANG_DANISH
 {0x00,0x20,0x56,0x55,0x56,0x38},	/* 0x10 ,a_circ    RO e2 */
 {0x00,0x20,0x55,0x56,0x55,0x78},	/* 0x11 ,a_breve   RO e3 */
 {0x00,0x20,0x56,0x55,0x56,0x38},	/* 0x12 ,a_ring    DK e5 */
 {0x00,0x34,0x54,0x7C,0x54,0x58},	/* 0x13 ,a_elig    DK e6 */
 {0x00,0x00,0x02,0x7D,0x42,0x00},	/* 0x14 ,i_circ    RO ee */
 {0x00,0xB8,0x64,0x54,0x4C,0x3A},	/* 0x15 ,o_slash   DK f8 */
 {0x00,0x04,0xAA,0x6A,0x2A,0x10},	/* 0x16 ,s-cedil   RO ba */
 {0x00,0x04,0xBE,0x44,0x24,0x00},	/* 0x17 ,t-cedil   RO fe */
 {0x00,0x78,0x16,0x15,0x16,0x78},	/* 0x18 ,A_circ    RO c2 */
 {0x00,0x70,0x29,0x26,0x29,0x70},	/* 0x19 ,A_breve   RO c3 */
 {0x00,0x70,0x2A,0x25,0x2A,0x70},	/* 0x1a ,A_ring    DK c5 */
 {0x90,0x1C,0x13,0x7F,0x49,0x49},	/* 0x1b ,A_elig    DK c6 */
 {0x00,0x00,0x46,0x7D,0x46,0x00},	/* 0x1c ,I_circ    RO ce */
 {0x00,0xBC,0x62,0x5A,0x46,0x3D},	/* 0x1d ,O_slash   DK d8 */
 {0x00,0x16,0xB5,0x55,0x15,0x08},	/* 0x1e ,S-cedil   RO aa */
 {0x00,0x01,0x01,0xBF,0x41,0x01},	/* 0x1f ,T-cedil   RO de */
 #else	
 {0x00,0x0C,0x10,0x10,0x10,0x7C},	/* 0xc0 - GR_OFFSET2,Cyr_tsch */                  
 {0x00,0x7C,0x40,0x7C,0x40,0x7C},	/* 0xc1 - GR_OFFSET2,Cyr_sch */
 {0x00,0x04,0x7C,0x50,0x50,0x20},	/* 0xc2 - GR_OFFSET2,Cyr_hh */
 {0x00,0x7C,0x50,0x20,0x00,0x7C},	/* 0xc3 - GR_OFFSET2,Cyr_y */
 {0x00,0x7C,0x50,0x50,0x20,0x00},	/* 0xc4 - GR_OFFSET2,Cyr_ww */
 {0x00,0x28,0x44,0x54,0x54,0x38},	/* 0xc5 - GR_OFFSET2,Cyr_e */
 {0x00,0x7C,0x10,0x38,0x44,0x38},	/* 0xc6 - GR_OFFSET2,Cyr_ju */
 {0x00,0x08,0x54,0x34,0x14,0x7C},	/* 0xc7 - GR_OFFSET2,Cyr_ja */
 {0x00,0xE0,0x51,0x4F,0x41,0xFF},	/* 0xe0 - GR_OFFSET3,Cyr_D       */
 {0x00,0x7F,0x40,0x40,0x40,0xFF},	/* 0xe1 - GR_OFFSET3,Cyr_C       */
 {0x00,0x7F,0x40,0x7F,0x40,0xFF},	/* 0xe2 - GR_OFFSET3,Cyr_Schtsch */
 {0x00,0xE0,0x54,0x4C,0x44,0xFC},	/* 0xe3 - GR_OFFSET3,Cyr_d       */
 {0x00,0x18,0x24,0x7E,0x24,0x18},	/* 0xe4 - GR_OFFSET3,Cyr_f       */
 {0x00,0x7C,0x40,0x40,0x40,0xFC},	/* 0xe5 - GR_OFFSET3,Cyr_c       */
 {0x00,0x7C,0x40,0x7C,0x40,0xFC},	/* 0xe6 - GR_OFFSET3,Cyr_schtsch */
 {0x00,0x03,0x0F,0x3F,0x0F,0x03},	/* 0x1f  */
//*******************************************************************
 #endif                              
{0x00,0x00,0x00,0x00,0x00,0x00},	/* 0x20 ' ' */
{0x00,0x00,0x06,0x5F,0x06,0x00},	/* 0x21 '!' */
{0x00,0x03,0x05,0x03,0x05,0x00},	/* 0x22 '"' */
{0x00,0x24,0x7E,0x24,0x7E,0x24},	/* 0x23 '#' */                           
{0x00,0x48,0x54,0xFF,0x54,0x24},	/* 0x24 '$' */
{0x00,0x63,0x13,0x08,0x64,0x63},	/* 0x25 '%' */
{0x00,0x36,0x49,0x56,0x20,0x50},	/* 0x26 '&' */
{0x00,0x00,0x0A,0x06,0x00,0x00},	/* 0x27 ''' */
{0x00,0x00,0x3E,0x41,0x00,0x00},	/* 0x28 '(' */
{0x00,0x00,0x41,0x3E,0x00,0x00},	/* 0x29 ')' */ 
{0x00,0x14,0x08,0x3E,0x08,0x14},	/* 0x2a '*' */
{0x00,0x08,0x08,0x3E,0x08,0x08},	/* 0x2b '+' */
{0x00,0x00,0xA0,0x60,0x00,0x00},	/* 0x2c ',' */
{0x00,0x08,0x08,0x08,0x08,0x08},	/* 0x2d '-' */
{0x00,0x00,0x60,0x60,0x00,0x00},	/* 0x2e '.' */
{0x00,0x20,0x10,0x08,0x04,0x02},	/* 0x2f '/' */
{0x00,0x3E,0x51,0x49,0x45,0x3E},	/* 0x30 '0' */
{0x00,0x00,0x42,0x7F,0x40,0x00},	/* 0x31 '1' */
{0x00,0x62,0x51,0x49,0x49,0x46},	/* 0x32 '2' */
{0x00,0x22,0x49,0x49,0x49,0x36},	/* 0x33 '3' */                           
{0x00,0x18,0x14,0x12,0x7F,0x10},	/* 0x34 '4' */
{0x00,0x2F,0x49,0x49,0x49,0x31},	/* 0x35 '5' */
{0x00,0x3C,0x4A,0x49,0x49,0x30},	/* 0x36 '6' */
{0x00,0x01,0x71,0x09,0x05,0x03},	/* 0x37 '7' */
{0x00,0x36,0x49,0x49,0x49,0x36},	/* 0x38 '8' */
{0x00,0x06,0x49,0x49,0x29,0x1E},	/* 0x39 '9' */                           
{0x00,0x00,0x6C,0x6C,0x00,0x00},	/* 0x3a ':' */
{0x00,0x00,0xEC,0x6C,0x00,0x00},	/* 0x3b ';' */
{0x00,0x08,0x14,0x22,0x41,0x00},	/* 0x3c '<' */
{0x00,0x24,0x24,0x24,0x24,0x24},	/* 0x3d '=' */
{0x00,0x00,0x41,0x22,0x14,0x08},	/* 0x3e '>' */
{0x00,0x02,0x01,0x59,0x09,0x06},	/* 0x3f '?' */
{0x00,0x3E,0x41,0x5D,0x55,0x1E},	/* 0x40 '@' */
{0x00,0x7E,0x11,0x11,0x11,0x7E},	/* 0x41 'A' */
{0x00,0x7F,0x49,0x49,0x49,0x36},	/* 0x42 'B' */
{0x00,0x3E,0x41,0x41,0x41,0x22},	/* 0x43 'C' */
{0x00,0x7F,0x41,0x41,0x41,0x3E},	/* 0x44 'D' */
{0x00,0x7F,0x49,0x49,0x49,0x41},	/* 0x45 'E' */
{0x00,0x7F,0x09,0x09,0x09,0x01},	/* 0x46 'F' */
{0x00,0x3E,0x41,0x49,0x49,0x7A},	/* 0x47 'G' */
{0x00,0x7F,0x08,0x08,0x08,0x7F},	/* 0x48 'H' */
{0x00,0x00,0x41,0x7F,0x41,0x00},	/* 0x49 'I' */
{0x00,0x30,0x40,0x40,0x40,0x3F},	/* 0x4a 'J' */
{0x00,0x7F,0x08,0x14,0x22,0x41},	/* 0x4b 'K' */
{0x00,0x7F,0x40,0x40,0x40,0x40},	/* 0x4c 'L' */
{0x00,0x7F,0x02,0x04,0x02,0x7F},	/* 0x4d 'M' */
{0x00,0x7F,0x02,0x04,0x08,0x7F},	/* 0x4e 'N' */
{0x00,0x3E,0x41,0x41,0x41,0x3E},	/* 0x4f 'O' */      
{0x00,0x7F,0x09,0x09,0x09,0x06},	/* 0x50 'P' */
{0x00,0x3E,0x41,0x51,0x21,0x5E},	/* 0x51 'Q' */
{0x00,0x7F,0x09,0x09,0x19,0x66},	/* 0x52 'R' */
{0x00,0x26,0x49,0x49,0x49,0x32},	/* 0x53 'S' */
{0x00,0x01,0x01,0x7F,0x01,0x01},	/* 0x54 'T' */
{0x00,0x3F,0x40,0x40,0x40,0x3F},	/* 0x55 'U' */
{0x00,0x1F,0x20,0x40,0x20,0x1F},	/* 0x56 'V' */                           
{0x00,0x3F,0x40,0x3C,0x40,0x3F},	/* 0x57 'W' */
{0x00,0x63,0x14,0x08,0x14,0x63},	/* 0x58 'X' */
{0x00,0x07,0x08,0x70,0x08,0x07},	/* 0x59 'Y' */
{0x00,0x71,0x49,0x45,0x43,0x00},	/* 0x5a 'Z' */
{0x00,0x00,0x7F,0x41,0x41,0x00},	/* 0x5b '[' */
{0x00,0x02,0x04,0x08,0x10,0x20},	/* 0x5c '\' */
{0x00,0x00,0x41,0x41,0x7F,0x00},	/* 0x5d ']' */
{0x00,0x04,0x02,0x01,0x02,0x04},	/* 0x5e '^' */
{0x80,0x80,0x80,0x80,0x80,0x80},	/* 0x5f '_' */
{0x00,0x00,0x03,0x05,0x00,0x00},	/* 0x60 '`' */
{0x00,0x20,0x54,0x54,0x54,0x38},	/* 0x61 'a' */
{0x00,0x3F,0x44,0x44,0x44,0x38},	/* 0x62 'b' */
{0x00,0x38,0x44,0x44,0x44,0x28},	/* 0x63 'c' */
{0x00,0x38,0x44,0x44,0x44,0x3F},	/* 0x64 'd' */
{0x00,0x38,0x54,0x54,0x54,0x18},	/* 0x65 'e' */
{0x00,0x08,0x7E,0x09,0x0A,0x00},	/* 0x66 'f' */
{0x00,0x98,0xA4,0xA4,0x94,0x7C},	/* 0x67 'g' */
{0x00,0x7F,0x04,0x04,0x78,0x00},	/* 0x68 'h' */
{0x00,0x00,0x00,0x7D,0x40,0x00},	/* 0x69 'i' */
{0x00,0x40,0x80,0x84,0x7D,0x00},	/* 0x6a 'j' */
{0x00,0x7F,0x10,0x28,0x44,0x00},	/* 0x6b 'k' */
{0x00,0x00,0x00,0x7F,0x40,0x00},	/* 0x6c 'l' */
{0x00,0x7C,0x04,0x78,0x04,0x78},	/* 0x6d 'm' */
{0x00,0x7C,0x04,0x04,0x78,0x00},	/* 0x6e 'n' */
{0x00,0x38,0x44,0x44,0x44,0x38},	/* 0x6f 'o' */
{0x00,0xFC,0x24,0x44,0x44,0x38},	/* 0x70 'p' */
{0x00,0x38,0x44,0x44,0x24,0xFC},	/* 0x71 'q' */
{0x00,0x04,0x78,0x04,0x04,0x08},	/* 0x72 'r' */
{0x00,0x48,0x54,0x54,0x54,0x20},	/* 0x73 's' */
{0x00,0x04,0x3F,0x44,0x24,0x00},	/* 0x74 't' */
{0x00,0x3C,0x40,0x40,0x20,0x7C},	/* 0x75 'u' */
{0x00,0x1C,0x20,0x40,0x20,0x1C},	/* 0x76 'v' */
{0x00,0x3C,0x40,0x30,0x40,0x3C},	/* 0x77 'w' */
{0x00,0x6C,0x10,0x10,0x6C,0x00},	/* 0x78 'x' */
{0x00,0x9C,0xA0,0x60,0x3C,0x00},	/* 0x79 'y' */
{0x00,0x64,0x54,0x54,0x4C,0x00},	/* 0x7a 'z' */                           
{0x00,0x08,0x3E,0x41,0x41,0x00},	/* 0x7b '{' */
{0x00,0x00,0x00,0x77,0x00,0x00},	/* 0x7c '|' */                           
{0x00,0x00,0x41,0x41,0x3E,0x08},	/* 0x7d '}' */
{0x00,0x04,0x02,0x04,0x02,0x00},	/* 0x7e '~' */  
{0x00,0x3C,0x26,0x23,0x26,0x3C},	/* 0x7f  */
//*************************************************  
 #if defined LANG_CZECH || defined LANG_SLOVAK
 {0x00,0x04,0x3F,0x44,0x25,0x00},	/* 0x80 ,t_caron   bb */
 {0x00,0x3C,0x40,0x42,0x41,0x3C},	/* 0x81 ,u_acute   fa */
 {0x00,0x3C,0x41,0x40,0x41,0x3C},	/* 0x82 ,u_uml     fc */
 {0x00,0x38,0x42,0x45,0x42,0x38},	/* 0x83 ,u_ring    f9 */
 {0x00,0x9C,0xA0,0x62,0x3D,0x00},	/* 0x84 ,y_acute   fd */
 {0x00,0x64,0x55,0x56,0x4D,0x00},	/* 0x85 ,z_caron   b9 */
 {0x00,0x78,0x14,0x16,0x15,0x78},	/* 0x86 ,A_acute   c1 */
 {0x00,0x78,0x25,0x26,0x25,0x78},	/* 0x87 ,A_uml     c4 */
 {0x00,0x3C,0x43,0x42,0x43,0x24},	/* 0x88 ,C_caron   c8 */
 {0x00,0x7E,0x43,0x42,0x43,0x3C},	/* 0x89 ,D_caron   cf */
 {0x00,0x7C,0x54,0x56,0x55,0x44},	/* 0x8a ,E_acute   c9 */
 {0x00,0x7C,0x55,0x56,0x55,0x44},	/* 0x8b ,E_caron   cc */
 {0x00,0x00,0x00,0x7E,0x01,0x00},	/* 0x8c ,I_acute   cd */
 {0x00,0x7E,0x41,0x40,0x40,0x40},	/* 0x8d 'L_acute   c5 */
 {0x00,0x7F,0x40,0x43,0x40,0x40},	/* 0x8e 'L_caron   a5 */
 {0x00,0x7C,0x09,0x12,0x21,0x7C},	/* 0x8f ,N_caron   d2 */
 {0x00,0x38,0x44,0x46,0x45,0x38},	/* 0x90 ,O_acute   d3 */
 {0x00,0x3D,0x42,0x42,0x3D,0x00},	/* 0x91 ,O_uml     d6 */
 {0x00,0x38,0x46,0x45,0x46,0x38},	/* 0x92 ,O_circ    d4 */
 {0x00,0x7C,0x14,0x16,0x2D,0x40},	/* 0x93 ,R_acute   c0 */
 {0x00,0x7E,0x13,0x12,0x2B,0x44},	/* 0x94 ,R_caron   d8 */
 {0x00,0x24,0x4B,0x4A,0x53,0x24},	/* 0x95 ,S_caron   a9 */
 {0x00,0x02,0x03,0x7E,0x03,0x02},	/* 0x96 ,T_caron   ab */
 {0x00,0x3F,0x40,0x42,0x41,0x3F},	/* 0x97 ,U_acute   da */
 {0x00,0x3C,0x41,0x40,0x41,0x3C},	/* 0x98 ,U_uml     dc */
 {0x00,0x07,0x08,0x73,0x08,0x07},	/* 0x99 ,Y_acute   dd */
 {0x00,0x62,0x53,0x5A,0x4B,0x46},	/* 0x9a ,Z_caron   ae */
//**********************************************************
 #elif defined LANG_POLISH 
 {0x00,0x7F,0x40,0x7F,0x40,0x7F},	/* 0x80 ,Z_acute   ac */
 {0x00,0x62,0x52,0x5B,0x4A,0x46},	/* 0x81 ,Z_dot     af */
//*********************************************************
 #elif defined LCD_CYRILLIC                                                              
 {0x00,0x7F,0x49,0x49,0x49,0x33},	/* 0x80 ,Cyr_B */     
 {0x00,0x7F,0x01,0x01,0x01,0x03},	/* 0x81 ,Cyr_G */
 {0x00,0x7C,0x55,0x54,0x55,0x00},	/* 0x82 ,Cyr_Jo */
 {0x00,0x77,0x08,0x7F,0x08,0x77},	/* 0x83 ,Cyr_Zsch */
 {0x00,0x41,0x49,0x49,0x49,0x36},	/* 0x84 ,Cyr_Z */
 {0x00,0x7F,0x10,0x08,0x04,0x7F},	/* 0x85 ,Cyr_I */
 {0x00,0x7C,0x21,0x12,0x09,0x7C},	/* 0x86 ,Cyr_J */
 {0x00,0x20,0x41,0x3F,0x01,0x7F},	/* 0x87 ,Cyr_L */
 {0x00,0x7F,0x01,0x01,0x01,0x7F},	/* 0x88 ,Cyr_P */
 {0x00,0x47,0x28,0x10,0x08,0x07},	/* 0x89 ,Cyr_U */
 {0x00,0x1C,0x22,0x7F,0x22,0x1C},	/* 0x8a ,Cyr_F */
 {0x00,0x07,0x08,0x08,0x08,0x7F},	/* 0x8b ,Cyr_Tsch */
 {0x00,0x7F,0x40,0x7F,0x40,0x7F},	/* 0x8c ,Cyr_Sch */
 {0x00,0x01,0x7F,0x48,0x48,0x30},	/* 0x8d ,Cyr_HH */
 {0x00,0x7F,0x48,0x30,0x00,0x7F},	/* 0x8e ,Cyr_Y */
 {0x00,0x22,0x41,0x49,0x49,0x3E},	/* 0x8f ,Cyr_E */
 {0x00,0x7F,0x08,0x3E,0x41,0x3E},	/* 0x90 ,Cyr_Ju */
 {0x00,0x46,0x29,0x19,0x09,0x7F},	/* 0x91 ,Cyr_Ja */
 {0x00,0x3C,0x4A,0x4A,0x49,0x31},	/* 0x92 ,Cyr_b */
 {0x00,0x7C,0x54,0x54,0x28,0x00},	/* 0x93 ,Cyr_v */
 {0x00,0x7C,0x04,0x04,0x04,0x0C},	/* 0x94 ,Cyr_g */
 {0x00,0x38,0x55,0x54,0x55,0x18},	/* 0x95 ,Cyr_jo */
 {0x00,0x6C,0x10,0x7C,0x10,0x6C},	/* 0x96 ,Cyr_zsch */
 {0x00,0x44,0x44,0x54,0x54,0x28},	/* 0x97 ,Cyr_z */
 {0x00,0x7C,0x20,0x10,0x08,0x7C},	/* 0x98 ,Cyr_i */
 {0x00,0x78,0x42,0x24,0x12,0x78},	/* 0x99 ,Cyr_j */
 {0x00,0x7C,0x10,0x28,0x44,0x00},	/* 0x9a ,Cyr_k */
 {0x00,0x20,0x44,0x3C,0x04,0x7C},	/* 0x9b ,Cyr_l */
 {0x00,0x7C,0x08,0x10,0x08,0x7C},	/* 0x9c ,Cyr_m */
 {0x00,0x7C,0x10,0x10,0x10,0x7C},	/* 0x9d ,Cyr_n */                        
 {0x00,0x7C,0x04,0x04,0x04,0x7C},	/* 0x9e ,Cyr_p */
 {0x00,0x04,0x04,0x7C,0x04,0x04},	/* 0x9f ,Cyr_t */
 #endif
};
#else
 #ifndef __ASSEMBLER__
 extern const unsigned char PROGMEM font[CHAR_COUNT][FONT_WIDTH];
 #endif
#endif
 /* ****************************** EOF ******************** */
